@@ -32,14 +32,15 @@ import urllib
 import math
 import time
 
-
-
 def version():
-    print('目前版本:2.6')
+    print('目前版本:2.6.1')
     return None
 
 def changelog():
     '''
+    **版本2.6.1更新日志**
+    1.baidu_sentiment函数新增client_list可选参数,默认为已有的7个可用apply_id&key
+    
     **版本2.6更新日志**
     -----------------------------
     1.模块更名为srm_help\n
@@ -778,17 +779,17 @@ def scihub_download(doi_data, save_path, doi_column='DI', csv_encoding='utf-8-si
     return doi_data
 
 def baidu_sentiment(data, text_column, save=True, save_path = '',
-                    csv_encoding='utf-8-sig'):
+                    csv_encoding='utf-8-sig',
+                    client_list = [('jZgx0XTi08BKfLX0jNpmLea9','3f4AijnG0G59NTXCennNmuvUGZ7qM0Fu'),
+                                   ('onZ56rV2ZsMSGInLCGc6Cn24','3wePxTCcsxq7dCsT4os8Oqv6QKthS9py'),
+                                   ('Crynr1MkXIWVENHcvUXZdFTr','8v6P4ilp2guA9nLvHFojBfMBKHprGXP1'),
+                                   ('NlG9P9ObmKoFpcVgg5GS0zrf','CM2zvwxbf72KclGu3OfgqfRfAlOSGY4U'),
+                                   ('hSPjgCW5EazNml4OMaYSzzwL','uYjNbyiuV7zO0YwNDshreM9V8xSBIXvO'),
+                                   ('1hH4CSbGgPpEIAPxThbnNNSA','EOeWlRZq5TTb6NnGQoVzzBlfVnqDFQni'),
+                                   ('q7wedj0Zo5tlxga4uunU08e9','UUQ3CcHHlfG71mlA02GqK8zo3GS9QeaS')]):
     '''百度平台限制了每个client_id的分析速度上限时2条/每秒,因此开多个线程一起算'''
     data[text_column] = data[text_column].apply(str)
     data_num = len(data)    
-    client_list = [('jZgx0XTi08BKfLX0jNpmLea9', '3f4AijnG0G59NTXCennNmuvUGZ7qM0Fu'),
-                   ('onZ56rV2ZsMSGInLCGc6Cn24', '3wePxTCcsxq7dCsT4os8Oqv6QKthS9py'),
-                   ('Crynr1MkXIWVENHcvUXZdFTr','8v6P4ilp2guA9nLvHFojBfMBKHprGXP1'),
-                   ('NlG9P9ObmKoFpcVgg5GS0zrf','CM2zvwxbf72KclGu3OfgqfRfAlOSGY4U'),
-                   ('hSPjgCW5EazNml4OMaYSzzwL','uYjNbyiuV7zO0YwNDshreM9V8xSBIXvO'),
-                   ('1hH4CSbGgPpEIAPxThbnNNSA','EOeWlRZq5TTb6NnGQoVzzBlfVnqDFQni'),
-                   ('q7wedj0Zo5tlxga4uunU08e9','UUQ3CcHHlfG71mlA02GqK8zo3GS9QeaS')]
     client_num = len(client_list)#账号数量等于线程数量
     #将data按线程数量进行等分切割
     data_list = []
